@@ -13,6 +13,7 @@
 # limitations under the License.
 
 import os
+import re
 
 
 def are_all_elements_unique(elements):
@@ -33,3 +34,13 @@ def write_files_to_list(files, alias, output_dir):
         for filename in files:
             handle.write(filename + "\n")
     return list_filename
+
+
+def get_valid_filename(s):
+    """Return string with characters not allowed in filenames replaced by underscore."""
+    return re.sub(r'[^-.0-9a-zA-Z]+', '_', s)
+
+
+def validate_aliases(aliases):
+    """Checks that each alias remains unique when converted to a valid filename."""
+    return len(set(get_valid_filename(s) for s in aliases)) == len(aliases)
